import { ref, onMounted, onUnmounted, Ref } from 'vue';
import { useI18n } from '../../../locales';
import { useBasicStore } from '../../../stores/basic';
import { storeToRefs } from 'pinia';
export default function useUserInfo() {
  const { t } = useI18n();
  const basicStore = useBasicStore();
  const { userName } = storeToRefs(basicStore);

  const userInfoRef = ref();
  const showUserControl = ref(false);
  const showUserNameEdit: Ref<boolean> = ref(false);

  const tempUserName = ref('');
  /**
     * Whether to display the user information operation box
     *
     * 是否显示用户信息操作框
    **/
  function handleUserControl() {
    showUserControl.value = !showUserControl.value;
  }

  /**
     * Hide the user information action box
     *
     * 隐藏用户信息操作框
    **/
  function hideUserControl(event: Event) {
    if (!userInfoRef.value?.contains(event.target)) {
      showUserControl.value = false;
    }
  }

  /**
     * Show change name dialog
     *
     * 展示修改名字 dialog
    **/
  function showEditUserNameDialog() {
    showUserNameEdit.value = true;
    tempUserName.value = userName.value;
  }

  /**
     * Close the modify name dialog
     *
     * 关闭修改名字的 dialog
    **/
  function closeEditUserNameDialog() {
    showUserNameEdit.value = false;
  }

  onMounted(() => {
    window?.addEventListener('click', hideUserControl);
  });

  onUnmounted(() => {
    window?.removeEventListener('click', hideUserControl);
  });
  return {
    t,
    showUserControl,
    showUserNameEdit,
    userInfoRef,
    tempUserName,
    handleUserControl,
    showEditUserNameDialog,
    closeEditUserNameDialog,
  };
}
